@@ -1,7 +1,7 @@
 package RSS::From::Forum::vBulletin;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -159,7 +159,7 @@ RSS::From::Forum::vBulletin - Generate an RSS page by parsing vBulletin forum di
 
 =head1 VERSION
 
-This document describes version 0.08 of RSS::From::Forum::vBulletin (from Perl distribution RSS-From-Forum-vBulletin), released on 2015-08-18.
+This document describes version 0.09 of RSS::From::Forum::vBulletin (from Perl distribution RSS-From-Forum-vBulletin), released on 2015-09-04.
 
 =head1 SYNOPSIS
 
@@ -172,13 +172,11 @@ This document describes version 0.08 of RSS::From::Forum::vBulletin (from Perl d
 
 =head2 get_rss_from_forum(%args) -> [status, msg, result, meta]
 
-{en_US Generate an RSS page by parsing vBulletin forum display page}.
+Generate an RSS page by parsing vBulletin forum display page.
 
-{en_US 
 Many vBulletin forums do not turn on RSS feeds. This function parses vBulletin
 forum display page and create a simple RSS page so you can subscribe to it using
 RSS.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -186,19 +184,15 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ua> => I<obj>
 
-{en_US Supply a custom LWP::UserAgent object}.
+Supply a custom LWP::UserAgent object.
 
-{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
-}
 
 =item * B<url>* => I<str>
 
-{en_US Forum URL (the forum display page)}.
+Forum URL (the forum display page).
 
-{en_US 
 Usually it's of the form: http://host/path/forumdisplay.php?f=XXX
-}
 
 =back
 
